// Copyright Earl Warren <contact@earl-warren.org>
// Copyright Loïc Dachary <loic@dachary.org>
// SPDX-License-Identifier: MIT

package repository

import (
	"context"
	"testing"

	"code.forgejo.org/f3/gof3/v3/f3"
	helpers_repository "code.forgejo.org/f3/gof3/v3/forges/helpers/repository"
	"code.forgejo.org/f3/gof3/v3/logger"
	"code.forgejo.org/f3/gof3/v3/tree/generic"
	"code.forgejo.org/f3/gof3/v3/util"

	"github.com/stretchr/testify/assert"
)

type repositoryMock struct {
	logger.Logger
	url string
}

func newRepositoryMock(url string) *repositoryMock {
	r := &repositoryMock{
		url: url,
	}
	r.SetLogger(logger.NewLogger())
	return r
}

func (o *repositoryMock) GetNode() generic.NodeInterface      { return nil }
func (o *repositoryMock) GetRepositoryPushURL() string        { return o.url }
func (o *repositoryMock) GetRepositoryInternalRefs() []string { return []string{} }
func (o *repositoryMock) GetRepositoryURL() string            { return o.url }
func (o *repositoryMock) ToFormat() f3.Interface              { return nil }
func (o *repositoryMock) SetFetchFunc(func(ctx context.Context, destination string, internalRefs []string)) {
}

func TestRepositoryHelper(t *testing.T) {
	url := t.TempDir()
	repositoryHelper := NewTestHelper(t, url, nil)
	repositoryHelper.CreateRepositoryContent("").PushMirror()

	h := helpers_repository.NewHelper(newRepositoryMock(url))
	assert.True(t, util.FileExists(h.Fetch(context.Background())))
}
